# -*- coding: utf-8 -*-
"""
Automatically generated by Colaboratory.

Original file is located at
    https://colab.research.google.com/drive/1Cw-N18R71M1LrwWE3BetROKSP4ryI5Lz
"""
# !pip install gtts

from gtts import gTTS 
from IPython.display import Audio 
import time

'''
Essa função recebe dois parâmetros, o primeiro é o texto que vai falar e o 
segundo é o nome do arquivo que vai gerar.

Se ela não receber nenhum desses dois parâmetros ela utiliza os dois que foram passados
por padrão.

'''
def falar(text='EXECUTOU!!!',outputName='speaker'):
  tts = gTTS(text,lang='pt-br') 
  tts.save(f'{outputName}.mp3')
  sound_file = f'{outputName}.mp3'
  time.sleep(1)
  return Audio(sound_file, autoplay=True,) 

if __name__ == "__main__":
    falar()



#-*- coding: utf-8 -*-
from setuptools import setup

with open("README.md", "r") as fh:
    readme = fh.read()

setup(name='fala_assis',
    version='0.0.1',
    url='https://github.com/OseiasBeu/AssistenteDeFala',
    license='MIT License',
    author='Oseias Beu',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='oseiasbeu@outlook.com',
    keywords='Assistente de Fala',
    description=u'Assistente de fala que avisa um portador de deficiência visual quando o programa executou',
    packages=['fala_assis'],
    install_requires=['gtts','IPython'],)